package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppletService;

/**
 * 平台&服务介绍信息Service接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface IAppletServiceService 
{
    /**
     * 查询平台&服务介绍信息
     * 
     * @param id 平台&服务介绍信息主键
     * @return 平台&服务介绍信息
     */
    public AppletService selectAppletServiceById(Long id);

    /**
     * 查询平台&服务介绍信息列表
     * 
     * @param appletService 平台&服务介绍信息
     * @return 平台&服务介绍信息集合
     */
    public List<AppletService> selectAppletServiceList(AppletService appletService);

    /**
     * 新增平台&服务介绍信息
     * 
     * @param appletService 平台&服务介绍信息
     * @return 结果
     */
    public int insertAppletService(AppletService appletService);

    /**
     * 修改平台&服务介绍信息
     * 
     * @param appletService 平台&服务介绍信息
     * @return 结果
     */
    public int updateAppletService(AppletService appletService);

    /**
     * 批量删除平台&服务介绍信息
     * 
     * @param ids 需要删除的平台&服务介绍信息主键集合
     * @return 结果
     */
    public int deleteAppletServiceByIds(Long[] ids);

    /**
     * 删除平台&服务介绍信息信息
     * 
     * @param id 平台&服务介绍信息主键
     * @return 结果
     */
    public int deleteAppletServiceById(Long id);
}
